==> cdktf-provider-google-13.1.0-sources.jar: com/hashicorp/cdktf/providers/google/compute_instance_group_manager/ComputeInstanceGroupManagerInstanceLifecyclePolicy.java <==
package com.hashicorp.cdktf.providers.google.compute_instance_group_manager;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-17T04:17:39.565Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.computeInstanceGroupManager.ComputeInstanceGroupManagerInstanceLifecyclePolicy")
@software.amazon.jsii.Jsii.Proxy(ComputeInstanceGroupManagerInstanceLifecyclePolicy.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ComputeInstanceGroupManagerInstanceLifecyclePolicy extends software.amazon.jsii.JsiiSerializable {

    /**
     * Specifies whether to apply the group's latest configuration when repairing a VM.
     * <p>
     * Valid options are: YES, NO. If YES and you updated the group's instance template or per-instance configurations after the VM was created, then these changes are applied when VM is repaired. If NO (default), then updates are applied in accordance with the group's update policy type.
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/compute_instance_group_manager#force_update_on_repair ComputeInstanceGroupManager#force_update_on_repair}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getForceUpdateOnRepair() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ComputeInstanceGroupManagerInstanceLifecyclePolicy}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ComputeInstanceGroupManagerInstanceLifecyclePolicy}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ComputeInstanceGroupManagerInstanceLifecyclePolicy> {
        java.lang.String forceUpdateOnRepair;

        /**
         * Sets the value of {@link ComputeInstanceGroupManagerInstanceLifecyclePolicy#getForceUpdateOnRepair}
         * @param forceUpdateOnRepair Specifies whether to apply the group's latest configuration when repairing a VM.
         *                            Valid options are: YES, NO. If YES and you updated the group's instance template or per-instance configurations after the VM was created, then these changes are applied when VM is repaired. If NO (default), then updates are applied in accordance with the group's update policy type.
         *                            
         *                            Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/compute_instance_group_manager#force_update_on_repair ComputeInstanceGroupManager#force_update_on_repair}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder forceUpdateOnRepair(java.lang.String forceUpdateOnRepair) {
            this.forceUpdateOnRepair = forceUpdateOnRepair;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ComputeInstanceGroupManagerInstanceLifecyclePolicy}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ComputeInstanceGroupManagerInstanceLifecyclePolicy build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ComputeInstanceGroupManagerInstanceLifecyclePolicy}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ComputeInstanceGroupManagerInstanceLifecyclePolicy {
        private final java.lang.String forceUpdateOnRepair;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.forceUpdateOnRepair = software.amazon.jsii.Kernel.get(this, "forceUpdateOnRepair", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.forceUpdateOnRepair = builder.forceUpdateOnRepair;
        }

        @Override
        public final java.lang.String getForceUpdateOnRepair() {
            return this.forceUpdateOnRepair;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getForceUpdateOnRepair() != null) {
                data.set("forceUpdateOnRepair", om.valueToTree(this.getForceUpdateOnRepair()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.computeInstanceGroupManager.ComputeInstanceGroupManagerInstanceLifecyclePolicy"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ComputeInstanceGroupManagerInstanceLifecyclePolicy.Jsii$Proxy that = (ComputeInstanceGroupManagerInstanceLifecyclePolicy.Jsii$Proxy) o;

            return this.forceUpdateOnRepair != null ? this.forceUpdateOnRepair.equals(that.forceUpdateOnRepair) : that.forceUpdateOnRepair == null;
        }

        @Override
        public final int hashCode() {
            int result = this.forceUpdateOnRepair != null ? this.forceUpdateOnRepair.hashCode() : 0;
            return result;
        }
    }
}

==> cdktf-provider-google-13.13.0-sources.jar: com/hashicorp/cdktf/providers/google/compute_instance_group_manager/ComputeInstanceGroupManagerInstanceLifecyclePolicy.java <==
package com.hashicorp.cdktf.providers.google.compute_instance_group_manager;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.96.0 (build 921e240)", date = "2024-04-09T03:36:13.541Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.computeInstanceGroupManager.ComputeInstanceGroupManagerInstanceLifecyclePolicy")
@software.amazon.jsii.Jsii.Proxy(ComputeInstanceGroupManagerInstanceLifecyclePolicy.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ComputeInstanceGroupManagerInstanceLifecyclePolicy extends software.amazon.jsii.JsiiSerializable {

    /**
     * Default behavior for all instance or health check failures.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/compute_instance_group_manager#default_action_on_failure ComputeInstanceGroupManager#default_action_on_failure}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getDefaultActionOnFailure() {
        return null;
    }

    /**
     * Specifies whether to apply the group's latest configuration when repairing a VM.
     * <p>
     * Valid options are: YES, NO. If YES and you updated the group's instance template or per-instance configurations after the VM was created, then these changes are applied when VM is repaired. If NO (default), then updates are applied in accordance with the group's update policy type.
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/compute_instance_group_manager#force_update_on_repair ComputeInstanceGroupManager#force_update_on_repair}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getForceUpdateOnRepair() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ComputeInstanceGroupManagerInstanceLifecyclePolicy}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ComputeInstanceGroupManagerInstanceLifecyclePolicy}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ComputeInstanceGroupManagerInstanceLifecyclePolicy> {
        java.lang.String defaultActionOnFailure;
        java.lang.String forceUpdateOnRepair;

        /**
         * Sets the value of {@link ComputeInstanceGroupManagerInstanceLifecyclePolicy#getDefaultActionOnFailure}
         * @param defaultActionOnFailure Default behavior for all instance or health check failures.
         *                               Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/compute_instance_group_manager#default_action_on_failure ComputeInstanceGroupManager#default_action_on_failure}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder defaultActionOnFailure(java.lang.String defaultActionOnFailure) {
            this.defaultActionOnFailure = defaultActionOnFailure;
            return this;
        }

        /**
         * Sets the value of {@link ComputeInstanceGroupManagerInstanceLifecyclePolicy#getForceUpdateOnRepair}
         * @param forceUpdateOnRepair Specifies whether to apply the group's latest configuration when repairing a VM.
         *                            Valid options are: YES, NO. If YES and you updated the group's instance template or per-instance configurations after the VM was created, then these changes are applied when VM is repaired. If NO (default), then updates are applied in accordance with the group's update policy type.
         *                            
         *                            Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/compute_instance_group_manager#force_update_on_repair ComputeInstanceGroupManager#force_update_on_repair}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder forceUpdateOnRepair(java.lang.String forceUpdateOnRepair) {
            this.forceUpdateOnRepair = forceUpdateOnRepair;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ComputeInstanceGroupManagerInstanceLifecyclePolicy}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ComputeInstanceGroupManagerInstanceLifecyclePolicy build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ComputeInstanceGroupManagerInstanceLifecyclePolicy}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ComputeInstanceGroupManagerInstanceLifecyclePolicy {
        private final java.lang.String defaultActionOnFailure;
        private final java.lang.String forceUpdateOnRepair;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.defaultActionOnFailure = software.amazon.jsii.Kernel.get(this, "defaultActionOnFailure", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.forceUpdateOnRepair = software.amazon.jsii.Kernel.get(this, "forceUpdateOnRepair", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.defaultActionOnFailure = builder.defaultActionOnFailure;
            this.forceUpdateOnRepair = builder.forceUpdateOnRepair;
        }

        @Override
        public final java.lang.String getDefaultActionOnFailure() {
            return this.defaultActionOnFailure;
        }

        @Override
        public final java.lang.String getForceUpdateOnRepair() {
            return this.forceUpdateOnRepair;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getDefaultActionOnFailure() != null) {
                data.set("defaultActionOnFailure", om.valueToTree(this.getDefaultActionOnFailure()));
            }
            if (this.getForceUpdateOnRepair() != null) {
                data.set("forceUpdateOnRepair", om.valueToTree(this.getForceUpdateOnRepair()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.computeInstanceGroupManager.ComputeInstanceGroupManagerInstanceLifecyclePolicy"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ComputeInstanceGroupManagerInstanceLifecyclePolicy.Jsii$Proxy that = (ComputeInstanceGroupManagerInstanceLifecyclePolicy.Jsii$Proxy) o;

            if (this.defaultActionOnFailure != null ? !this.defaultActionOnFailure.equals(that.defaultActionOnFailure) : that.defaultActionOnFailure != null) return false;
            return this.forceUpdateOnRepair != null ? this.forceUpdateOnRepair.equals(that.forceUpdateOnRepair) : that.forceUpdateOnRepair == null;
        }

        @Override
        public final int hashCode() {
            int result = this.defaultActionOnFailure != null ? this.defaultActionOnFailure.hashCode() : 0;
            result = 31 * result + (this.forceUpdateOnRepair != null ? this.forceUpdateOnRepair.hashCode() : 0);
            return result;
        }
    }
}
